@@ -250,11 +250,6 @@ func (a *Actuator) sync(ctx context.Context, cr *minterv1.CredentialsRequest) er
 	logger := a.getLogger(cr)
 	logger.Debug("running sync")
 
-	infraName, err := utils.LoadInfrastructureName(a.client.Client, logger)
-	if err != nil {
-		return err
-	}
-
 	// Should we update anything
 	needsUpdate, err := a.needsUpdate(ctx, cr)
 	if err != nil {
@@ -270,6 +265,11 @@ func (a *Actuator) sync(ctx context.Context, cr *minterv1.CredentialsRequest) er
 		return nil
 	}
 
+	infraName, err := utils.LoadInfrastructureName(a.client.Client, logger)
+	if err != nil {
+		return err
+	}
+
 	infraResourceGroups, err := loadAzureInfrastructureResourceGroups(a.client.Client, logger)
 	if err != nil {
 		return err
@@ -707,14 +707,9 @@ func (a *Actuator) getLogger(cr *minterv1.CredentialsRequest) log.FieldLogger {
 	})
 }
 
+// Upgradeable returns a ClusterOperator status condition for the upgradeable type
+// if the system is considered not upgradeable. Otherwise, return nil as the default
+// value is for things to be upgradeable.
 func (a *Actuator) Upgradeable(mode operatorv1.CloudCredentialsMode) *configv1.ClusterOperatorStatusCondition {
-	upgradeableCondition := &configv1.ClusterOperatorStatusCondition{
-		Status: configv1.ConditionTrue,
-		Type:   configv1.OperatorUpgradeable,
-	}
-	return upgradeableCondition
-}
-
-func (a *Actuator) GetUpcomingCredSecrets() []types.NamespacedName {
-	return []types.NamespacedName{}
+	return nil
 }
